@@ -330,8 +330,8 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
 @task
-def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True",buildWorker="True",buildScheduler="False"):
-    
+def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildWorker="True", buildScheduler="False"):
+
     # ensure maven installs all build tools
     local("pwd")
     local('mvn clean install -DskipTests')
@@ -354,7 +354,9 @@ def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True",buildWork
     if buildScheduler in TRUTH_VALUES:
         local('mkdir -p deploy/scheduler-worker/config')
         local('mkdir -p deploy/scheduler-worker/lib')
+
         local('cp config/logback.xml deploy/scheduler-worker/config/')
+        local('cp config/quartz.properties deploy/scheduler-worker/config/')
         local('cp -r scheduler-worker/target/lib/ deploy/scheduler-worker/')
         local('cp scheduler-worker/target/*SNAPSHOT.jar deploy/scheduler-worker/')
         if prodSecrets in TRUTH_VALUES:
@@ -738,6 +740,13 @@ def reload_node(processName):
 
     sudo("%s restart %s" % (supervisor, processName))
 
+@task
+@parallel
+def reload_script(processName,reloadScript="/data/deploy/current/finish-deploy.sh"):
+    swap_code()
+
+    sudo("%s %s" % (reloadScript, processName))
+
 
 @task
 def reload_nginx():
